@@ -47,6 +47,8 @@ public class CommandThread extends AgentThread {
     //ロガー
 	static private Log log = LogFactory.getLog(CommandThread.class);
 
+	// ジョブを起こす（Runtime.execする）際にシリアル化するための専用ロックオブジェクト
+	private static final Object lockNewProcess = new Object();
 	
 	/**
 	 * デバッグ用メイン処理
@@ -146,11 +148,13 @@ public class CommandThread extends AgentThread {
 		        //終了を送信
 		        info.setStatus(RunStatusConstant.ERROR);
 		        info.setTime(new Date());
-		        info.setErrorMessage("The execution user of the command and agent's user are different. ");
-		        info.setMessage("");
+				String errMsg = "The execution user of the command and agent's user are different. " +
+				"execUser=[" + m_info.getUser() + "], agentUser=[" + sysUserName + "]";
+				info.setErrorMessage(errMsg);
+				info.setMessage("");
 		        m_sendQueue.put(info);
 		        
-		        log.error("The execution user of the command and agent's user are different. ");
+				log	.error(errMsg);
 		        log.info("run end");
 		        
 		        //実行履歴削除メッセージ送信
@@ -209,7 +213,12 @@ public class CommandThread extends AgentThread {
 	    		    log.info("Command Execute:" + cmd[i]);
 	            }
 		    }
-		    process = runtime.exec(cmd);
+		    // JVM（Windows環境）の不具合（？）でRuntime.execの並列実行多重度を上げた
+		    // 場合に問題が発生することがあるため、同時にただ１つのスレッドのみがexecを実行
+		    // できるように、staticなロックオブジェクトのsynchronizedによってシリアル化する
+		    synchronized(lockNewProcess) {
+		    	process = runtime.exec(cmd);
+		    }
 		} catch (IOException e) {
 			log.error(e);
 			m_errMsg = e.getMessage();
@@ -322,7 +331,7 @@ public class CommandThread extends AgentThread {
 					} else {
 						
 						// バッファがフルになった場合、ログを出力して、メッセージ文字列を生成
-						if (total == m_limit_orgmsg) {
+						if (total >= m_limit_orgmsg) {
 							log.info("stdout / errout limit(" + m_limit_orgmsg+ " Byte) over");
 							out_string = new String(m_readbuf);
 							bufIsFull = true;
@@ -335,8 +344,9 @@ public class CommandThread extends AgentThread {
 				}
 				
 				// バッファがフルになっていない場合は、メッセージ文字列を生成
-				if (!bufIsFull) out_string = new String(m_readbuf);
-					
+//				if (!bufIsFull) out_string = new String(m_readbuf);
+				if (!bufIsFull) out_string = new String(m_readbuf, 0, total);
+				
 			} catch (IOException e) {
 				log.error(e);
 			}
