@@ -40,6 +40,7 @@ import javax.naming.InitialContext;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import com.clustercontrol.agent.util.InternalLogger;
 import com.clustercontrol.agent.util.RunHistoryUtil;
 import com.clustercontrol.jobmanagement.bean.CommandConstant;
 import com.clustercontrol.jobmanagement.bean.CommandTypeConstant;
@@ -56,7 +57,7 @@ import com.clustercontrol.jobmanagement.message.RunResultInfo;
  * 
  * Topicでマネージャからのジョブ実行指示を受け取ります。
  * 
- * @version $Revision: 886 $
+ * @version $Revision: 3158 $
  * @since 1.0.0
  * 
  */
@@ -266,6 +267,9 @@ public class ReceiveTopic implements MessageListener, ExceptionListener {
 
     	log.error(arg0);
     	
+    	// syslogにログ出力
+		InternalLogger.error("hinemos_jobagent: A problem has been detected with the connection to MGR");
+    	
         setErrFlg(true);
         
         terminate();
