@@ -16,6 +16,12 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.agent;
 
 import java.util.Properties;
+import java.util.concurrent.Callable;
+import java.util.concurrent.ExecutorService;
+import java.util.concurrent.Executors;
+import java.util.concurrent.Future;
+import java.util.concurrent.ThreadFactory;
+import java.util.concurrent.TimeUnit;
 
 import javax.jms.ExceptionListener;
 import javax.jms.JMSException;
@@ -31,6 +37,7 @@ import javax.naming.InitialContext;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import com.clustercontrol.agent.util.InternalLogger;
 import com.clustercontrol.jobmanagement.bean.QueueConstant;
 import com.clustercontrol.jobmanagement.message.RunResultInfo;
 
@@ -40,7 +47,7 @@ import com.clustercontrol.jobmanagement.message.RunResultInfo;
  * エージェントからの戻りメッセージはこのメソッドを用いて
  * マネージャに返送されます。
  *
- * @version $Revision: 757 $
+ * @version $Revision: 3402 $
  * @since 1.0.0
  */
 public class SendQueue implements ExceptionListener {
@@ -50,6 +57,8 @@ public class SendQueue implements ExceptionListener {
 	private static final String QUEUE_USER_NAME = "queue.user.name";
 
 	private static final String QUEUE_USER_PASSWORD = "queue.user.password";
+	
+	private static final long SEND_TIMEOUT = 60 * 1000l;
 
 	private Properties m_props;
 
@@ -67,7 +76,18 @@ public class SendQueue implements ExceptionListener {
 
 	//ロガー
 	static private Log log = LogFactory.getLog(SendQueue.class);
-    
+	
+	// reInitialメソッドが複数スレッドから呼ばれないよにするロック用オブジェクト
+	private final Object reInitialLock = new Object();
+
+	// Queue送信処理が複数スレッドから呼ばれないよにするためのロック用オブジェクト
+	private final Object sendQueueLock = new Object();
+	
+	// 内部エラー出力抑制フラグ
+	// エージェント → マネージャ間通信に失敗した場合にエラー出力を行うが、
+	// 継続して通信できていない状態の場合は出力を制御する
+	volatile private boolean internalErroInhibitflag = false;
+	
 	/**
 	 * コンストラクタ
 	 * @param props プロパティファイル情報
@@ -93,29 +113,30 @@ public class SendQueue implements ExceptionListener {
 	/**
 	 *  再接続の処理を行います。<BR>
 	 */
-	synchronized private boolean reInitial() {
+	private boolean reInitial() {
+		synchronized (reInitialLock) {
+			boolean ret = false;
 
-		boolean ret = false;
+			log.info("再接続処理!");
 
-		log.info("再接続処理!");
+			terminate();
 
-		terminate();
+			if (initial()) {
 
-		if (initial()) {
+				ret = true;
 
-			ret = true;
+				log.info("再接続処理:成功!");
 
-			log.info("再接続処理:成功!");
-
-			//エラーフラグ解除
-			m_isErr = false;
+				//エラーフラグ解除
+				m_isErr = false;
 
 
-		} else {
-			log.info("再接続処理:失敗!");
+			} else {
+				log.info("再接続処理:失敗!");
+			}
+
+			return ret;
 		}
-
-		return ret;
 	}
 	/**
 	 * マネージャへの接続の終了処理を行います。<BR>
@@ -144,77 +165,46 @@ public class SendQueue implements ExceptionListener {
 	 * @param msg
 	 */
 	synchronized public boolean put(RunResultInfo info) {
-
-		if (m_isErr) {
-			reInitial();
-		}
-
-		QueueSender sender = null;
-//		for(int i = 0; i < 2 ;i ++) {
-//			try {
-//				//Sender作成
-//				sender = m_session.createSender(m_queue);
-//				//メッセージ作成
-//				ObjectMessage mess = m_session.createObjectMessage(info);
-//				//送信
-//				log.info("オブジェクトメッセージ送信!");
-//				sender.send(mess);
-//				
-//				return true;
-//	
-//			} catch (JMSException e) {
-//				log.error(e);
-//				log.info("オブジェクトメッセージ送信リトライ");
-//				
-//				try {
-//					wait(1000);
-//				} catch (InterruptedException e1) {
-//				}
-//				
-//				if(!reInitial()){
-//					return false;
-//				}
-//	
-//			} finally {
-//				try {
-//					if (sender != null)
-//						sender.close();
-//				} catch (Exception e1) {
-//				}
-//			}
-//		
-//		}
-		while(true) {
-			try {
-				//Sender作成
-				sender = m_session.createSender(m_queue);
-				//メッセージ作成
-				ObjectMessage mess = m_session.createObjectMessage(info);
-				//送信
-				log.info("オブジェクトメッセージ送信 : SessionID=" + info.getSessionId() + ", JobID=" + info.getJobId() + ", CommandType=" + info.getCommandType());
-				sender.send(mess);
+		log.debug("put() start  : "  + info.getCommandType() + ", " + info.getSessionId()+ ", " + info.getJobId());
+			
+		ExecutorService es = null;
+		Future<?> task = null;
+		try {
+			// Executorオブジェクトの生成
+			SenderThreadFactory threadFactory = new SenderThreadFactory(info.getSessionId());
+			es = Executors.newSingleThreadExecutor(threadFactory);
 				
-				return true;
-	
-			} catch (Exception e) {
-				log.error(e);
-				log.info("オブジェクトメッセージ送信リトライ");
-				
-				try {
-					wait(m_interval);
-				} catch (InterruptedException e1) {
-				}
-				
-				reInitial();
-	
-			} finally {
-				try {
-					if (sender != null)
-						sender.close();
-				} catch (Exception e1) {
-				}
+			// タスクの実行
+			log.debug("put() submit : "  + info.getCommandType() + ", " + info.getSessionId()+ ", " + info.getJobId());
+			task = es.submit(new Sender(info));
+			task.get(SEND_TIMEOUT, TimeUnit.MILLISECONDS);
+			return true;
+		} catch (Exception e) {
+			if(internalErroInhibitflag == true){
+				// 抑制されている場合は簡略なメッセージとする
+				log.error("Failed to connect to MGR");
+			} else {
+				log.error("Failed to connect to MGR", e);
 			}
+			
+			// 抑制されていない場合に出力する
+			if(internalErroInhibitflag == false){
+				// syslogにログ出力
+				InternalLogger.error("hinemos_jobagent: Failed to connect to MGR");
+				// エラーログ出力抑制フラグを設定する
+				internalErroInhibitflag = true;
+			}
+		} finally {
+			// Senderのcall()メソッドが終了した後でExecutorServiceのshutdown()メソッドを実行するように待ち合わせる
+    		synchronized (sendQueueLock) {
+    			log.debug("put() end    : "  + info.getCommandType() + ", " + info.getSessionId()+ ", " + info.getJobId());
+    			if(es != null){
+    				es.shutdown();
+    			}
+    		}
 		}
+			
+		return false;
 	}
 
 	/**
@@ -273,6 +263,9 @@ public class SendQueue implements ExceptionListener {
 			} catch (Exception e1) {
 			}
 		}
+		// エラー出力抑制フラグをクリア
+		internalErroInhibitflag = false;
+		
 		return true;
 
 	}
@@ -289,4 +282,74 @@ public class SendQueue implements ExceptionListener {
         
         terminate();
     }
+    
+    /**
+     * Queueメッセージ送信処理を実行するタスク用クラス
+     */
+    private class Sender implements Callable<Boolean> {
+    	private RunResultInfo m_info;
+    	
+    	public Sender(RunResultInfo info){
+    		m_info = info;
+    	}
+    	
+    	public Boolean call() throws Exception {
+    		synchronized (sendQueueLock) {
+    			if (m_isErr) {
+    				reInitial();
+    			}
+    			
+    			QueueSender sender = null;
+    			while(true) {
+    				try {
+    					//Sender作成
+    					sender = m_session.createSender(m_queue);
+    					//メッセージ作成
+    					ObjectMessage mess = m_session.createObjectMessage(m_info);
+    					//送信
+    					log.info("オブジェクトメッセージ送信 : SessionID=" + m_info.getSessionId()
+    							+ ", JobID=" + m_info.getJobId()
+    							+ ", CommandType=" + m_info.getCommandType());
+    					sender.send(mess);
+    					
+    					return true;
+    					
+    				} catch (Exception e) {
+    					log.error(e);
+    					log.info("オブジェクトメッセージ送信リトライ");
+    					
+    					try {
+//    						wait(m_interval);
+    						Thread.sleep(m_interval);
+    					} catch (InterruptedException e1) {
+    					}
+    					
+    					reInitial();
+    					
+    				} finally {
+    					try {
+    						if (sender != null)
+    							sender.close();
+    					} catch (Exception e1) {
+    					}
+    				}
+    			}
+    		}
+    	}
+    }
+    
+    /**
+     * Queueメッセージ送信処理を実行するタスク用のThreadFactory
+     */
+	private class SenderThreadFactory implements ThreadFactory {
+		private final String m_threadName;
+		
+		public SenderThreadFactory(String threadName){
+			m_threadName = threadName;
+		}
+		
+		public Thread newThread(Runnable r) {
+			return new Thread(r, "Sender-" + m_threadName);
+		}
+	}
 }
