@@ -17,7 +17,6 @@ package com.clustercontrol.logagent;
 
 import java.util.ArrayList;
 import java.util.Collection;
-import java.util.Hashtable;
 import java.util.Iterator;
 import java.util.Properties;
 import java.util.Timer;
@@ -39,8 +38,8 @@ import javax.naming.InitialContext;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import com.clustercontrol.logagent.TransferLogManager.LogThreadManageInfo;
 import com.clustercontrol.logagent.TransferLogManager.LogTransferFileInfoFacility;
+import com.clustercontrol.logagent.util.InternalLogger;
 import com.clustercontrol.logtransfer.bean.LogTransferFileInfo;
 import com.clustercontrol.logtransfer.bean.TopicConstant;
 
@@ -197,10 +196,8 @@ public class ReceiveTopic implements MessageListener, ExceptionListener {
         
         log.debug("onMessage start");
         String facilityId;
-        boolean initFlg;
         try {
 			facilityId = message.getStringProperty("FacilityId");
-			initFlg = message.getBooleanProperty("Init");
 	        log.debug("onMessage target facility : " + facilityId);
 		} catch (JMSException e1) {
 			log.error("受信メッセージが不正", e1);
@@ -233,11 +230,6 @@ public class ReceiveTopic implements MessageListener, ExceptionListener {
 					}
 				}
             	
-				// 接続・再接続時のみログ転送情報リフレッシュ
-				if(initFlg){
-					log.debug("ログ転送情報をリフレッシュ");
-					m_logManager.refreshRunTransferLog(facilityId, list);		
-				}
 				// ログ転送
             	m_logManager.setTransferLogInfo(facilityId, list);
                 
@@ -260,6 +252,9 @@ public class ReceiveTopic implements MessageListener, ExceptionListener {
 
     	log.error(arg0.getMessage(), arg0);
     	
+    	// syslogにログ出力
+		InternalLogger.error("hinemos_logagent: A problem has been detected with the connection to MGR");
+    	
         setErrFlg(true);
         
         terminate();
