@@ -27,6 +27,7 @@ import java.util.ArrayList;
 import java.util.Calendar;
 import java.util.Date;
 import java.util.GregorianCalendar;
+import java.util.Iterator;
 import java.util.Locale;
 
 import javax.ejb.CreateException;
@@ -68,6 +69,7 @@ import com.clustercontrol.maintenance.factory.SelectMaintenanceInfo;
 import com.clustercontrol.maintenance.factory.SelectMaintenanceKeepMst;
 import com.clustercontrol.maintenance.factory.SelectMaintenanceTypeMst;
 import com.clustercontrol.maintenance.factory.SelectSchedule;
+import com.clustercontrol.maintenance.util.MaintenanceProperties;
 import com.clustercontrol.util.apllog.AplLogger;
 
 /**
@@ -97,7 +99,7 @@ import com.clustercontrol.util.apllog.AplLogger;
 public abstract class MaintenanceControllerBean implements SessionBean {
 
    protected static Log m_log = LogFactory.getLog( MaintenanceControllerBean.class );
-   
+
 	/** コンテキスト情報 */
 	@SuppressWarnings("unused")
 	private SessionContext m_context;
@@ -488,7 +490,7 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 	public int deleteEventLog(String keep_id) throws FinderException, NamingException, CreateException, SQLException {
 		m_log.debug("deleteEventLog()");
 		
-		int ret = -1;
+		int ret = 0;
 		Connection conn = null;
 		Statement stmt = null;
 		
@@ -555,7 +557,8 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 	public int deleteJobHistory(String keep_id) throws FinderException, NamingException, CreateException, SQLException {
 		m_log.debug("deleteJobHistory()");
 		
-		int ret = -1;
+		// 削除件数
+		int ret = 0;
 		Connection conn = null;
 		Statement stmt = null;
 		
@@ -568,84 +571,89 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 			stmt = conn.createStatement();
 			
 			//削除対象となるsession_idをセレクトする
-			String sql_select_list = "select session_id from cc_job_session_job " +
+			String sql_select_list = "select distinct session_id from cc_job_session_job " +
 					"where (status='300' OR status='301')" +
 					" AND end_date < '" + timestamp.toString() + "'" +
 					" AND session_id IN (select session_id from cc_job_session);";
 			
-			ResultSet res = stmt.executeQuery(sql_select_list);
-			StringBuffer sb = new StringBuffer();
-			while(res.next()){
-				sb.append("'");
-				sb.append(res.getString(1));
-				sb.append("'");
-				if (!res.isLast()) {
-					sb.append(", ");					
-				}
-			}
+			m_log.debug("sql : " + sql_select_list);
 			
-			m_log.debug("delete list : " + sb.toString());
-			if (sb.length() == 0) {
+			//削除対象ジョブのセッションIDを取得する
+			ResultSet res = stmt.executeQuery(sql_select_list);
+			
+			//セッションIDのリストを分割し、ArrayListに入れる
+			ArrayList<String> sessionIdsList = convertSessionIdsToArrayList(res);
+
+//			if (sb.length() == 0) {
+			if (sessionIdsList.size() == 0) {
 				ret = 0;
 				
 			} else {
 				
-				//削除用SQL文の定義、実行
-				StringBuffer sql = new StringBuffer();
-				sql.append("DELETE FROM cc_job_param_info WHERE session_id IN (" + sb.toString() + ");");
-				stmt.executeUpdate(sql.toString());
-				
-				sql.delete(0, sql.length());
-				sql.append("DELETE FROM cc_job_end_info WHERE session_id IN (" + sb.toString() + ");");
-				stmt.executeUpdate(sql.toString());
+				Iterator iterator = sessionIdsList.iterator();
+				while (iterator.hasNext()) {
+					
+					String sessionIdList = (String) iterator.next();
+					
+					m_log.debug("delete list : " + sessionIdList);
+					
+					//削除用SQL文の定義、実行
+					StringBuffer sql = new StringBuffer();
+					sql.append("DELETE FROM cc_job_param_info WHERE session_id IN (" + sessionIdList + ");");
+					stmt.executeUpdate(sql.toString());
+					
+					sql.delete(0, sql.length());
+					sql.append("DELETE FROM cc_job_end_info WHERE session_id IN (" + sessionIdList + ");");
+					stmt.executeUpdate(sql.toString());
+					
+					sql.delete(0, sql.length());
+					sql.append("DELETE FROM cc_job_notice_info WHERE session_id IN (" + sessionIdList + ");");
+					stmt.executeUpdate(sql.toString());
+					
+					sql.delete(0, sql.length());
+					sql.append("DELETE FROM cc_job_command_info WHERE session_id IN (" + sessionIdList + ");");
+					stmt.executeUpdate(sql.toString());
+					
+					sql.delete(0, sql.length());
+					sql.append("DELETE FROM cc_job_start_info WHERE session_id IN (" + sessionIdList + ");");
+					stmt.executeUpdate(sql.toString());
+					
+					sql.delete(0, sql.length());
+					sql.append("DELETE FROM cc_job_start_job_info WHERE session_id IN (" + sessionIdList + ");");
+					stmt.executeUpdate(sql.toString());
+					
+					sql.delete(0, sql.length());
+					sql.append("DELETE FROM cc_job_start_time_info WHERE session_id IN (" + sessionIdList + ");");
+					stmt.executeUpdate(sql.toString());
+					
+					sql.delete(0, sql.length());
+					sql.append("DELETE FROM cc_job_file_info WHERE session_id IN (" + sessionIdList + ");");
+					stmt.executeUpdate(sql.toString());
+					
+					sql.delete(0, sql.length());
+					sql.append("DELETE FROM cc_job_info WHERE session_id IN (" + sessionIdList + ");");
+					stmt.executeUpdate(sql.toString());
+					
+					sql.delete(0, sql.length());
+					sql.append("DELETE FROM cc_job_relation_info WHERE session_id IN (" + sessionIdList + ");");
+					stmt.executeUpdate(sql.toString());
+					
+					sql.delete(0, sql.length());
+					sql.append("DELETE FROM cc_job_session_node WHERE session_id IN (" + sessionIdList + ");");
+					stmt.executeUpdate(sql.toString());
 
-				
-				sql.delete(0, sql.length());
-				sql.append("DELETE FROM cc_job_notice_info WHERE session_id IN (" + sb.toString() + ");");
-				stmt.executeUpdate(sql.toString());
-				
-				sql.delete(0, sql.length());
-				sql.append("DELETE FROM cc_job_command_info WHERE session_id IN (" + sb.toString() + ");");
-				stmt.executeUpdate(sql.toString());
-				
-				sql.delete(0, sql.length());
-				sql.append("DELETE FROM cc_job_start_info WHERE session_id IN (" + sb.toString() + ");");
-				stmt.executeUpdate(sql.toString());
-				
-				sql.delete(0, sql.length());
-				sql.append("DELETE FROM cc_job_start_job_info WHERE session_id IN (" + sb.toString() + ");");
-				stmt.executeUpdate(sql.toString());
-				
-				sql.delete(0, sql.length());
-				sql.append("DELETE FROM cc_job_start_time_info WHERE session_id IN (" + sb.toString() + ");");
-				stmt.executeUpdate(sql.toString());
-				
-				sql.delete(0, sql.length());
-				sql.append("DELETE FROM cc_job_file_info WHERE session_id IN (" + sb.toString() + ");");
-				stmt.executeUpdate(sql.toString());
-				
-				sql.delete(0, sql.length());
-				sql.append("DELETE FROM cc_job_info WHERE session_id IN (" + sb.toString() + ");");
-				stmt.executeUpdate(sql.toString());
-				
-				sql.delete(0, sql.length());
-				sql.append("DELETE FROM cc_job_relation_info WHERE session_id IN (" + sb.toString() + ");");
-				stmt.executeUpdate(sql.toString());
-				
-				sql.delete(0, sql.length());
-				sql.append("DELETE FROM cc_job_session_node WHERE session_id IN (" + sb.toString() + ");");
-				stmt.executeUpdate(sql.toString());
-
-				sql.delete(0, sql.length());
-				sql.append("DELETE FROM cc_job_session_job WHERE session_id IN (" + sb.toString() + ");");
-				stmt.executeUpdate(sql.toString());
-				
-				//cc_job_sessionの削除件数を返り値とする
-				sql.delete(0, sql.length());
-				sql.append("DELETE FROM cc_job_session WHERE session_id IN (" + sb.toString() + ");");
-				ret = stmt.executeUpdate(sql.toString());
-				
-				m_log.debug("execute : " + sql.toString());
+					sql.delete(0, sql.length());
+					sql.append("DELETE FROM cc_job_session_job WHERE session_id IN (" + sessionIdList + ");");
+					stmt.executeUpdate(sql.toString());
+					
+					//cc_job_sessionの削除件数を返り値とする
+					sql.delete(0, sql.length());
+					sql.append("DELETE FROM cc_job_session WHERE session_id IN (" + sessionIdList + ");");
+					
+					//　削除件数を加算
+					ret = ret + stmt.executeUpdate(sql.toString());
+					
+				}
 			}
 
 			m_log.debug("delete count : " + ret);
@@ -686,7 +694,7 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 	public int deleteCollectiveRunHistory(String keep_id) throws FinderException, NamingException, CreateException, SQLException {
 		m_log.debug("deleteCollectiveRunHistory()");
 		
-		int ret = -1;
+		int ret = 0;
 		Connection conn = null;
 		Statement stmt = null;
 
@@ -698,41 +706,45 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 			stmt = conn.createStatement();
 			
 			//削除対象となるsession_idをセレクトする
-			String sql_select_list = "SELECT session_id from cc_crun_session" +
+			String sql_select_list = "SELECT distinct session_id from cc_crun_session" +
 					" WHERE end_date < '" + timestamp.toString() + "' AND status='300';";
 			
+			m_log.debug("sql : " + sql_select_list);
+			
+			//削除対象ジョブのセッションIDを取得する
 			ResultSet res = stmt.executeQuery(sql_select_list);
-			StringBuffer sb = new StringBuffer();
-			while(res.next()){
-				sb.append("'");
-				sb.append(res.getString(1));
-				sb.append("'");
-				if (!res.isLast()) {
-					sb.append(", ");					
-				}
-			}
 			
-			m_log.debug("delete list : " + sb.toString());
-			
-			if (sb.length() == 0) {
+			//セッションIDのリストを分割し、ArrayListに入れる
+			ArrayList<String> sessionIdsList = convertSessionIdsToArrayList(res);
+
+//			if (sb.length() == 0) {
+			if (sessionIdsList.size() == 0) {
 				ret = 0;
 			} else {
 				
-				//SQL文の定義、実行
-				StringBuffer sql = new StringBuffer();
-				sql.append("DELETE FROM cc_crun_session_detail WHERE session_id IN(" + sb.toString() + ");");
-				stmt.executeUpdate(sql.toString());						
-				
-				sql.delete(0, sql.length());
-				sql.append("DELETE FROM cc_crun_session_param WHERE session_id IN(" + sb.toString() + ");");
-				stmt.executeUpdate(sql.toString());			
-				
-				//cc_crun_sessionの削除件数を返り値とする
-				sql.delete(0, sql.length());
-				sql.append("DELETE FROM cc_crun_session WHERE session_id IN(" + sb.toString() + ");");
-				ret = stmt.executeUpdate(sql.toString());
-				
-				m_log.debug("execute : " + sql.toString());
+				Iterator iterator = sessionIdsList.iterator();
+				while (iterator.hasNext()) {
+					
+					String sessionIdList = (String) iterator.next();
+					
+					m_log.debug("delete list : " + sessionIdList);
+					
+					//SQL文の定義、実行
+					StringBuffer sql = new StringBuffer();
+					sql.append("DELETE FROM cc_crun_session_detail WHERE session_id IN(" + sessionIdList + ");");
+					stmt.executeUpdate(sql.toString());						
+					
+					sql.delete(0, sql.length());
+					sql.append("DELETE FROM cc_crun_session_param WHERE session_id IN(" + sessionIdList + ");");
+					stmt.executeUpdate(sql.toString());			
+					
+					//cc_crun_sessionの削除件数を返り値とする
+					sql.delete(0, sql.length());
+					sql.append("DELETE FROM cc_crun_session WHERE session_id IN(" + sessionIdList + ");");
+					
+					//　削除件数を加算
+					ret = ret + stmt.executeUpdate(sql.toString());
+				}
 			}
 			
 			m_log.debug("delete count : " + ret);
@@ -929,8 +941,9 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 	 * @throws CreateException 
 	 * @throws NamingException 
 	 * @throws FinderException 
+	 * @throws SchedulerException 
 	 */
-	public ArrayList getMaintenanceList() throws FinderException, NamingException, CreateException {
+	public ArrayList getMaintenanceList() throws FinderException, NamingException, CreateException, SchedulerException {
 		m_log.debug("getMaintenanceList()");
 		
 		SelectMaintenanceInfo select = new SelectMaintenanceInfo();
@@ -1197,7 +1210,8 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 	}
 	
 	private Timestamp getTimestamp(String keep_id) throws FinderException, NamingException, CreateException {
-		
+
+		m_log.debug("keep_id : " +  keep_id);
 		int order_no = 0;
 		
 		//削除対象外期間が設定されていた場合
@@ -1225,6 +1239,10 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 			calendar.add(Calendar.MONTH, -1);
 			break;
 			
+		case MaintenanceKeepMstConstant.TWO_MONTHS_INDEX:
+			calendar.add(Calendar.MONTH, -2);
+			break;
+			
 		case MaintenanceKeepMstConstant.THREE_MONTHS_INDEX:
 			calendar.add(Calendar.MONTH, -3);
 			break;
@@ -1238,10 +1256,65 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 			break;
 		}
 		
+		m_log.debug(calendar.getTime());
+		
 		return new Timestamp(calendar.getTimeInMillis());
 		
 	}
 	
+	/**
+	 * 
+	 * セッションIDのリストを分割し、ArrayListにつめるメソッド
+	 * 
+	 * セッションIDのリストは、カンマ区切りのString文字列である
+	 * 例 : session_id1, session_id2, session_id3, session_id4 ...
+	 * 
+	 * クラス変数limitで指定された数だけセッションIDが含まれるような、
+	 * 上記形式の文字列が、ArrayListの１要素となるように変換する
+	 * 
+	 * @param res
+	 * @return
+	 * @throws SQLException
+	 */
+	private ArrayList<String> convertSessionIdsToArrayList(ResultSet res) throws SQLException {
+		
+		//セッションIDのリストを半角スペース区切りから、コンマ区切りに変更する
+		ArrayList<String> sessionIdsList = new ArrayList<String>();
+		StringBuffer sb = new StringBuffer();
+		
+		// リストに追加したsession_id数のカウンタ
+		int count = 0;
+		while(res.next()){
+			
+			sb.append("'");
+			sb.append(res.getString(1));
+			sb.append("'");
+			sb.append(", ");
+			count++;
+			
+			// session_idリストが制限値に達していたら、
+			// 余分についているカンマを削除した後、
+			// 別のArrayListに登録して、初期化
+			if (count == MaintenanceProperties.getInstance().getDeleteBufSize()) {
+				// 余分に付いているカンマを削除
+				sb.delete(sb.length() - 2, sb.length());
+				m_log.debug("add list : " + sb.toString());
+				sessionIdsList.add(sb.toString());
+				sb.delete(0, sb.length());
+				count = 0;
+			}
+		}
+		
+		if (sb.length() > 0) {
+			// 余分に付いているカンマを削除
+			sb.delete(sb.length() - 2, sb.length());
+			// 残りを追加
+			sessionIdsList.add(sb.toString());
+		}
+		
+		return sessionIdsList;
+	}
+	
 	public void ejbRemove() throws EJBException, RemoteException {}
 
 	public void ejbActivate() throws EJBException, RemoteException {}
