@@ -1449,7 +1449,7 @@ public class CollectorBean implements EntityBean {
 		CalculatedDataDAO dao = new CalculatedDataDAO();
 		dao.deleteOverPresave(collectorID, startDate);
 		int count = dao.recountFromDB(collectorID);
-		if(count != 0){
+		if(count > -1){
 			this.setCollectCount(count);
 		}
 	}
