@@ -1,16 +1,16 @@
 /*
- 
- Copyright (C) 2006 NTT DATA Corporation
- 
+
+ Copyright (C) 2008 NTT DATA Corporation
+
  This program is free software; you can redistribute it and/or
  Modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation, version 2.
- 
+
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
- 
+
  */
 
 package com.clustercontrol.snmppoller;
@@ -45,13 +45,13 @@ import com.clustercontrol.sharedtable.bean.ValueObject;
 /**
  * SNMPのポーリングを実行するクラス
  * 
- * @version 2.0.0
+ * @version 2.4.2
  * @since 2.0.0
  */
 public class SnmpPoller implements SnmpHandler {
 	protected static Log m_log = LogFactory.getLog(SnmpPoller.class);
 
-	/** IPアドレス */
+	// IPアドレス（ポーリングの度に更新）
 	private String m_ipAddress;
 
 	// 収集のターゲットとなるOID（全てのポーリングが終了するまで値を保持）
@@ -59,44 +59,53 @@ public class SnmpPoller implements SnmpHandler {
 
 	// 収集を開始するOID（ポーリングの度に更新）
 	private ArrayList<SnmpObjectId> m_startOids;
-	
+
 	// 収集を終了するOID（ポーリングの度に更新）
 	private ArrayList<SnmpObjectId> m_stopOids;
-	
-	// 取得したデータを格納するテーブル
-	DataTable m_dataTable;
 
-	// メッセージ 
+	// 取得したデータを格納するテーブル（ポーリングの度に更新）
+	private DataTable m_dataTable;
+
+	// メッセージ（ポーリングの度に更新）
 	private String m_message = null;
 
 	// 待機フラグ
 	private boolean m_waitFlg;
-	
-	// 収集したOIDの最後のインデックスをチェックするか否かのフラグ	
+
+	// 収集したOIDの最後のインデックスをチェックするか否かのフラグ（ポーリングの度に更新）
 	private boolean m_indexCheckFlg = false;
 
-	// m_indexCheckFlg = true の場合にリトライした回数を保持
-	private int m_indexCheckRetryCount = 0;
+	// m_indexCheckFlg = true の場合に、取得したOIDのインデックスが異なることで
+	// リトライした回数を保持（ポーリングの度に更新）
+	private int m_indexCheckDiffIndexRetryCount = 0;
+
+	// m_indexCheckFlg = true の場合に、取得できたVarBindの数が異なることで
+	// リトライした回数を保持（ポーリングの度に更新）
+	private int m_indexCheckVarBindSizeRetryCount = 0;
+	
+	// m_indexCheckFlg = true の場合にリトライした回数の合計を保持（ポーリングの度に更新）
+	private int m_indexCheckRetryCountTotal = 0;
 	
 	// m_indexCheckFlg = true の場合にリトライする回数の最大値
-	private final int m_indexCheckRetryCountMax = 3;
-
+	private final int MAX_RETRY_COUNT = 10;
+	
 	// ポーリング対象のスコープを抜ける際のOIDが本当にそのスコープの最後のOIDなのかをチェックする
 	// （Net-SNMPのHOST-RESOURCES-MIBでプロセス情報を取得した際に、
 	//  プロセスのリストを最後まで取得できない場合があることへの対処）
 	// そのために最後のOIDでリトライ処理をするその回数を保持
+	// （ポーリングの度に更新）
 	private int m_indexCheckLastIndexRetryCount = 0;
-	
+
 	// 最期にポーリングを行なった際のOIDのリスト m_indexCheckFlg = true の場合に使用する
 	private ArrayList<String> m_lastPollingOids;
-	
+
 	// 全体的なポーリングをリトライするか否かのフラグ
 	private boolean m_retryFlg = false;
-	
+
 	// 全体的なポーリングのリトライ回数
-	private int m_retryCount = 1;
-	
-	// エラーコード
+	private final int m_retryCount = 1;
+
+	// エラーコード（ポーリングの度に更新）
 	private int m_errorCode = 0;
 
 	// エラーコード
@@ -106,16 +115,18 @@ public class SnmpPoller implements SnmpHandler {
 
 	// クラス変数の初期化
 	private void init(){
-		m_indexCheckRetryCount = 0;
+		m_indexCheckDiffIndexRetryCount = 0;
+		m_indexCheckVarBindSizeRetryCount = 0;
+		m_indexCheckRetryCountTotal = 0;
 		m_indexCheckLastIndexRetryCount = 0;
 		m_errorCode = Normal;
 		m_message = null;
 	}
-	
+
 	/**
 	 * メインルーチン　
-	 * IPアドレスと　Hashtableを受け取り、
-	 * ポーリングした結果をHashtableに代入する
+	 * IPアドレスと　DataTableを受け取り、
+	 * ポーリングした結果をDataTableに代入する
 	 *  
 	 * @param ipAddress IPアドレス
 	 * @param port ポート番号
@@ -134,20 +145,9 @@ public class SnmpPoller implements SnmpHandler {
 			String community, 
 			int retries, 
 			int timeout, 
-			List oidList,
+			List<String> oidList,
 			boolean indexCheckFlg,
 			DataTable table) {
-		// デバッグ出力
-		if (m_log.isDebugEnabled()) {
-			m_log.debug("polling() start :" + ipAddress.toString());
-			m_log.debug("Port      : " + port);
-			m_log.debug("Version   : " + version);
-			m_log.debug("Community : " + community);
-			m_log.debug("Retries   : " + retries);
-			m_log.debug("Timeout   : " + timeout);
-			m_log.debug("IndexCheckFlg : " + indexCheckFlg);
-		}
-		
 		// クラス変数を初期化
 		init();
 
@@ -171,6 +171,17 @@ public class SnmpPoller implements SnmpHandler {
 		if (community != null)
 			parms.setReadCommunity(community);
 
+		// デバッグ出力
+		if (m_log.isDebugEnabled()) {
+			m_log.debug("polling() start :" + ipAddress.toString());
+			m_log.debug("Port            : " + peer.getPort());
+			m_log.debug("Version         : " + peer.getParameters().getVersion());
+			m_log.debug("Community       : " + peer.getParameters().getReadCommunity());
+			m_log.debug("Retries         : " + peer.getRetries());
+			m_log.debug("Timeout         : " + peer.getTimeout());
+			m_log.debug("IndexCheckFlg   : " + indexCheckFlg);
+		}
+		
 		//　sessionを生成
 		SnmpSession session = null;
 		try {
@@ -193,17 +204,17 @@ public class SnmpPoller implements SnmpHandler {
 
 			SnmpPduRequest pdu = new SnmpPduRequest(SnmpPduPacket.GETNEXT);
 			pdu.setRequestId(SnmpPduPacket.nextSequence());
-			
-			Iterator itr = oidList.iterator();
+
+			Iterator<String> itr = oidList.iterator();
 			while (itr.hasNext()) {
 				m_oidText[i] = (String) itr.next();
-				
+
 				// OIDの最後が0で終わる場合は、.0を削除する
 				// GETNEXTで取得するため
 				if(m_oidText[i].endsWith(".0")){
 					m_oidText[i] = m_oidText[i].substring(0, m_oidText[i].lastIndexOf(".0"));
 				}
-				
+
 				// 開始OIDを設定
 				SnmpObjectId startOid = new SnmpObjectId(m_oidText[i]);
 
@@ -218,10 +229,10 @@ public class SnmpPoller implements SnmpHandler {
 				m_startOids.add(startOid);
 				m_stopOids.add(stopOid);
 				m_lastPollingOids.add(m_oidText[i]);
-				
+
 				i++;
 			}
-			
+
 			for (int count = 0; count < m_retryCount+1; count++) {
 				synchronized (session) {
 					m_waitFlg = true;
@@ -232,10 +243,13 @@ public class SnmpPoller implements SnmpHandler {
 						session.wait();
 					}
 				}
-				
+
 				if(m_retryFlg == false){
 					//　リトライしない
 					break;
+				} else {
+					// 一旦取得した全てのデータを削除してリトライ
+					m_dataTable.clear();
 				}
 			}
 		} catch (InterruptedException e) {
@@ -254,9 +268,8 @@ public class SnmpPoller implements SnmpHandler {
 				 * Joe-SNMPの不具合の回避コード
 				 * Joe-SNMPで不具合が修正されたら削除すること
 				 */
-				m_log
-						.warn("polling():" + m_ipAddress
-								+ " Session close failed");
+				m_log.warn("polling():" + m_ipAddress
+						+ " Session close failed");
 			}
 		}
 
@@ -267,8 +280,15 @@ public class SnmpPoller implements SnmpHandler {
 
 		}
 
+		// リトライ回数が多い場合は出力する
+		if(m_indexCheckRetryCountTotal >= 100){
+			m_log.warn("polling():" + m_ipAddress + 
+					" too many retries. count : " + m_indexCheckRetryCountTotal);
+		}
+		
 		// デバッグ出力
 		if (m_log.isDebugEnabled()) {
+			m_log.debug("polling() " + m_ipAddress + " retry total count : " + m_indexCheckRetryCountTotal);
 			m_log.debug("polling() end :" + ipAddress.toString());
 		}
 	}
@@ -296,10 +316,9 @@ public class SnmpPoller implements SnmpHandler {
 			}
 
 			if (pdu.getCommand() != SnmpPduPacket.RESPONSE) {
-				m_log
-						.error("polling() error :" + session.toString()
-								+ "  Received non-response command "
-								+ pdu.getCommand());
+				m_log.error("polling() error :" + session.toString()
+						+ "  Received non-response command "
+						+ pdu.getCommand());
 				synchronized (session) {
 					m_errorCode = InternalError;
 					session.notify();
@@ -324,28 +343,32 @@ public class SnmpPoller implements SnmpHandler {
 			// インデックスチェックフラグが設定されている場合にOIDの最後のインデックスが
 			// 一致しているか否かをチェックするのに使用
 			String lastIndexStr = null;
-			
+
 			// インデックスの最大値を保持する(m_indexCheckFlgがtrueの場合のみ利用)
+			// 取得できたOIDのインデックスに差異がない場合は-lのまま
 			int maxIndex = -1;
 
 			// 次回のポーリングでpduにセットするOIDの開始と終了のOIDを保持する
 			ArrayList<SnmpObjectId> nextStartOids = new ArrayList<SnmpObjectId>(m_startOids.size());
 			ArrayList<SnmpObjectId> nextStopOids = new ArrayList<SnmpObjectId>(m_stopOids.size());
-			// 最期にポーリングを行なった際のOIDのリスト(m_indexCheckFlg = true の場合に使用)
+			// 最期にポーリングを行なった際に取得したOIDのリスト(m_indexCheckFlg = true の場合に使用)
 			ArrayList<String> lastPollingOids = new ArrayList<String>(m_startOids.size());
+			// インデックスチェックが必要な場合は、この時点ではテーブルに反映することはできないため、
+			// 一時的にArrayListに保持する(m_indexCheckFlg = true の場合に使用)
+			ArrayList<ValueObject> entryBuffer = new ArrayList<ValueObject>(m_startOids.size());
 			
 			// pduの戻りとして帰ってきた SnmpVarBindを順次処理する
 			int length = pdu.getLength();
 			for (int i = 0; i < length; i++) {
 				SnmpVarBind var = pdu.getVarBindAt(i);
-				
+
 				// ポーリングの終了判定
 				// 条件：
 				// 戻りの型が EndOfMibView の場合
 				// 停止条件のOIDにマッチした場合は終了
 				if (var.getValue().typeId() == SnmpEndOfMibView.ASNTYPE
 						|| ((m_stopOids.get(i) != null && m_stopOids.get(i).compare(var.getName()) < 0))) {
-			
+
 					// 該当OIDの収集を終了します
 					if (m_log.isDebugEnabled()) {
 						m_log.debug(m_ipAddress + " stop polling. " + i + ", "
@@ -375,16 +398,13 @@ public class SnmpPoller implements SnmpHandler {
 					}
 					continue;
 				} else {
-					// 取得した値をテーブルに書き込むか否かのチェックフラグ
-					boolean setFlug = true;
-					
 					// インデックスチェックフラグが設定されている場合は、OIDの最後のインデックスが
 					// 一致しているか否かをチェックする
 					if (m_indexCheckFlg == true) {
-						if (lastIndexStr == null) {
+						if (lastIndexStr == null) { // ループの1回目（i=0の場合）
 							lastIndexStr = oidString.substring(oidString
 									.lastIndexOf(".")+1);
-						} else {
+						} else { // ループの2回目以降は値が設定されている
 							String indexStr = oidString.substring(oidString
 									.lastIndexOf(".")+1);
 
@@ -394,57 +414,57 @@ public class SnmpPoller implements SnmpHandler {
 										+ ", " + lastIndexStr + ", "
 										+ oidString);
 
-//								// 格納されたMIB値を削除します。
-//								for(int j=0; j <= i; j++){
-//									String removeOid = pdu.getVarBindAt(j).getName().toString();
-//									m_log.debug("remove " + m_ipAddress + ", " + removeOid);
-//									m_dataTable.removeValue(removeOid);
-//								}
-								
 								// 最大のインデックスを設定
 								int lastIndex = Integer.parseInt(lastIndexStr);
 								if(lastIndex > maxIndex){
 									maxIndex = lastIndex;
 								}
-
-								// 取得値をテーブルに書き込まないように設定
-								setFlug = false;
 							}
 							lastIndexStr = indexStr;
 						}
 					}
+
+					// デバッグ
+					if (m_log.isDebugEnabled()) {
+						m_log.debug("set " + m_ipAddress + ","
+								+ oidString + "," + time + ","
+								+ var.getValue().toString() + ", "
+								+ var.getValue());
+					}
 					
-					if (setFlug == true) {
-						// if (var.getValue() instanceof SnmpNoSuchInstance) {
-						// // 何もしない
-						// } else if (var.getValue() instanceof
-						// SnmpNoSuchObject) {
-						// // 何もしない
-						// } else if (var.getValue() instanceof SnmpV2Error) {
-						// // 何もしない
-						// } else if (var.getValue() instanceof SnmpNull) {
-						// // 何もしない
-						// } else
-						if (var.getValue() instanceof SnmpTimeTicks) {
-							// デバッグ
-							if (m_log.isDebugEnabled()) {
-								m_log.debug("set " + m_ipAddress + ","
-										+ oidString + "," + time + ","
-										+ var.getValue().toString());
-							}
-
-							long value = ((SnmpUInt32) var.getValue()).getValue();
-							m_dataTable.putValue(oidString, time, String.valueOf(value));
+					if (var.getValue() instanceof SnmpTimeTicks) {
+						long value = ((SnmpUInt32) var.getValue()).getValue();
+						
+						if(m_indexCheckFlg == true){
+							entryBuffer.add(new ValueObject(oidString, time, String.valueOf(value)));
+							
+							m_log.debug("snmpReceivedPdu() dataTable put : " +
+									"entryKey : " + oidString + 
+									", time : " + time +
+									", longValue : " + String.valueOf(value));
 						} else {
-							// デバッグ
-							if (m_log.isDebugEnabled()) {
-								m_log.debug("set " + m_ipAddress + ","
-										+ oidString + "," + time + ","
-										+ var.getValue().toString());
-							}
-
-							m_dataTable.putValue(oidString, time, var
-									.getValue().toString());
+							m_dataTable.putValue(oidString, time, String.valueOf(value));
+							
+							m_log.debug("snmpReceivedPdu() dataTable put : " +
+									"entryKey : " + oidString + 
+									", time : " + time +
+									", longValue : " + String.valueOf(value));
+						}
+					} else {
+						if(m_indexCheckFlg == true){
+							entryBuffer.add(new ValueObject(oidString, time, var.getValue().toString()));
+							
+							m_log.debug("snmpReceivedPdu() dataTable put : " +
+									"entryKey : " + oidString + 
+									", time : " + time +
+									", longValue : " + var.getValue().toString());
+						} else {
+							m_dataTable.putValue(oidString, time, var.getValue().toString());
+							
+							m_log.debug("snmpReceivedPdu() dataTable put : " +
+									"entryKey : " + oidString + 
+									", time : " + time +
+									", longValue : " + var.getValue().toString());
 						}
 					}
 
@@ -452,36 +472,77 @@ public class SnmpPoller implements SnmpHandler {
 					nextStartOids.add(m_startOids.get(i));
 					nextStopOids.add(m_stopOids.get(i));
 					nxt.addVarBind(new SnmpVarBind(var.getName()));
-					// 最期に実行したポーリングのOIDのリストを保持する
+					// 最期に実行したポーリングで取得したOIDのリストを保持する
 					// m_indexCheckFlg が true の場合のリトライ処理のため
 					lastPollingOids.add(var.getName().toString());
 				}
 			}
-			
+
 			// インデックスチェックを行なっている場合
 			if(m_indexCheckFlg == true){
-				// 次に実行するOIDが１つもない場合
-				if (lastPollingOids.size() == 0) {
-					// リトライ回数をリセット
-					m_indexCheckRetryCount = 0;
+				// 正常に値取得できている場合は、値をテーブルに設定する
+				if (maxIndex == -1
+						&& ((lastPollingOids.size() == m_lastPollingOids.size())
+								|| (lastPollingOids.size() == 0))) {
+					// 一時的にArrayListで保持されていた取得値をセットする
+					Iterator<ValueObject> itr = entryBuffer.iterator();
+					while(itr.hasNext()){
+						ValueObject entry = itr.next();
+						
+						// デバッグ
+						if (m_log.isDebugEnabled()) {
+							m_log.debug("set (buffer to table) " + m_ipAddress + ","
+									+ entry.getKey() + "," + time + ","
+									+ entry.getValue().toString() + ", "
+									+ entry.getValue());
+						}
+						
+						m_dataTable.putValue(entry);
+					}
 					
+					// リトライ回数をリセット
+					m_indexCheckDiffIndexRetryCount = 0;
+					m_indexCheckVarBindSizeRetryCount = 0;
+				} else {
+					m_log.debug("detect error. " + m_ipAddress);
+				}
+
+				// 対応しているエラーパターン（VarBindの数をn個とする）
+				// 1) n個全て取得できているが、対象のMIBツリーの最後ではない
+				// 2) n個全て取得できているが、indexが揃っていない（少なくともどれかのindexが異なる）
+				// 3) n個全ては取得できていない。かつ、indexが揃っていない（少なくともどれかのindexが異なる）
+				// 4) n個全ては取得できていないが、indexは全て同じ
+				if (lastPollingOids.size() == 0) {  // エラーパターン1への対応
+					// 次に実行するOIDが１つもない場合
+					// ポーリング対象のスコープを抜ける際のOIDが本当にそのスコープの最後のOIDなのかをチェックする
+					// （Net-SNMPのHOST-RESOURCES-MIBでプロセス情報を取得した際に、
+					//  プロセスのリストを最後まで取得できない場合があることへの対処）
+					
+					// リトライ回数をリセット
+					m_indexCheckDiffIndexRetryCount = 0;
+					m_indexCheckVarBindSizeRetryCount = 0;
+
 					if (m_indexCheckLastIndexRetryCount >= 1) {
+						// 2回連続で同じOID（同じVarBindのセット）でポーリングの結果、全てのポーリングの戻りの
+						// PDUに入っている「次の問い合わせ対象OID」が取得対象のMIBツリーからはずれているため
 						// 正常に取得できたと判断
 					} else {
+						// ポーリング対処のOIDのリストの全てが同時に終了した場合、
+						// 対象スコープを抜ける際のOIDが本当にそのスコープの最後のOIDなのかをチェックする。
+						// （Net-SNMPのHOST-RESOURCES-MIBでプロセス情報を取得した際に、
+						// プロセスのリストを最後まで取得できない場合があることへの対処）
 						if (m_log.isDebugEnabled()) {
 							m_log.debug("check retry. count="
 									+ m_indexCheckLastIndexRetryCount + " "
 									+ m_ipAddress);
 						}
 						
-						// ポーリング対処のOIDのリストの全てが同時に終了した場合、
-						// 対象スコープを抜ける際のOIDが本当にそのスコープの最後のOIDなのかをチェックする。
-						// （Net-SNMPのHOST-RESOURCES-MIBでプロセス情報を取得した際に、
-						// プロセスのリストを最後まで取得できない場合があることへの対処）
 						nextStartOids.clear();
 						nextStopOids.clear();
 						lastPollingOids.clear();
 						nxt = new SnmpPduRequest(SnmpPduPacket.GETNEXT);
+						nxt.setRequestId(SnmpPduPacket.nextSequence());
+
 						for (int i = 0; i < m_lastPollingOids.size(); i++) {
 							if (m_log.isDebugEnabled()) {
 								m_log.debug("retry last polling set VarBind "
@@ -497,88 +558,129 @@ public class SnmpPoller implements SnmpHandler {
 
 						// 最後のOIDでリトライ処理を実行した回数をカウントアップ
 						m_indexCheckLastIndexRetryCount++;
+						m_indexCheckRetryCountTotal++;
 					}
-				} else {
+				} else {  // エラーパターン1以外の対応（正常動作の場合も含む）
+					// 次に実行するOIDが１つ以上ある場合
+
+					// ログ出力
+					if (m_log.isDebugEnabled()) {
+						if (m_indexCheckLastIndexRetryCount != 0) {
+							m_log.debug("detect error." + m_ipAddress);
+						}
+					}
+					
 					// 最後のOIDでリトライ処理を実行した回数をリセット
 					m_indexCheckLastIndexRetryCount = 0;
-					
+
 					// インデックスの異なるものが戻ってきていた場合
-					// もしくは、前回ポーリング実視時と次回ポーリング予定のOIDの数がちがう場合
 					// 再度ポーリングを実行する
-					if (maxIndex > 0	||
-							(lastPollingOids.size() != 0
-									&& lastPollingOids.size() != m_lastPollingOids.size())) {
+					if (maxIndex >= 0){  // エラーパターン2or3の対応
 						// ログ出力
 						if (m_log.isDebugEnabled()){
-							m_log.debug("recovery retry!! " + m_ipAddress);
-						}
-						
-						// ログ出力
-						if(m_log.isDebugEnabled()){
-							if(maxIndex > 0){
-								m_log.debug("recovery(index not match) " + m_ipAddress);
-							} else {
-								m_log.debug("recovery(next count:" + lastPollingOids.size()
-										+ ") " + m_ipAddress);
-							}
-						}
-						
-						// 格納されたMIB値を削除します。
-						for(int j=0; j < pdu.getLength(); j++){
-							String removeOid = pdu.getVarBindAt(j).getName().toString();
-							m_log.debug("remove " + m_ipAddress + ", " + removeOid);
-							m_dataTable.removeValue(removeOid);
+							m_log.debug("recovery(index not match) " + m_ipAddress
+									+ "  max index:" + maxIndex
+									+ "  next VarBind size:" + lastPollingOids.size());
 						}
+
+//						// 格納されたMIB値を削除します。
+//						for(int j=0; j < pdu.getLength(); j++){
+//							String removeOid = pdu.getVarBindAt(j).getName().toString();
+//							m_log.debug("remove " + m_ipAddress + ", " + removeOid);
+//							m_dataTable.removeValue(removeOid);
+//						}
 						
 						nextStartOids.clear();
 						nextStopOids.clear();
 						lastPollingOids.clear();
 						nxt = new SnmpPduRequest(SnmpPduPacket.GETNEXT);
-						for (int i = 0; i < m_lastPollingOids.size(); i++) {
-							String nextOid = null;
-							if (m_indexCheckRetryCount < m_indexCheckRetryCountMax) {
-								
-								nextOid = m_lastPollingOids.get(i);
-								
-								// リトライ回数をカウントアップ
-								m_indexCheckRetryCount++;
-							} else {
+						nxt.setRequestId(SnmpPduPacket.nextSequence());
+
+						if(m_indexCheckDiffIndexRetryCount < MAX_RETRY_COUNT){
+							for (int i = 0; i < m_lastPollingOids.size(); i++) {
 								String lastOid = m_lastPollingOids.get(i);
 								// 最大のインデックスのものがリトライによって収集されるように
 								// maxIndex-lをインデックスに設定する
-								nextOid = lastOid.substring(0,
-										lastOid.lastIndexOf(".") + 1)
-										+ (maxIndex-1);
-								
-								
+								String nextOid = lastOid.substring(0, lastOid.lastIndexOf(".") + 1)
+								+ (maxIndex - 1);
+
+								nextStartOids.add(m_startOids.get(i));
+								nextStopOids.add(m_stopOids.get(i));
+								nxt.addVarBind(new SnmpVarBind(nextOid));
+								lastPollingOids.add(nextOid);
+							
 								// ログ出力
-								if(m_log.isDebugEnabled()){
-									if(m_indexCheckLastIndexRetryCount != 0){
-										m_log.debug("recovery miss!!" + m_ipAddress);
-									}
+								if (m_log.isDebugEnabled()) {
+									m_log.debug("set VarBind " + m_ipAddress + "," + nextOid);
 								}
-								
-								// リトライ回数をリセット
-								m_indexCheckRetryCount = 0;
 							}
+						} else { // リトライ回数の上限を超えた場合
+							m_log.error("too many retries(index not match). " + m_ipAddress 
+									+ " count:" + m_indexCheckDiffIndexRetryCount);
+							// 収集したデータを全てクリアする
+							m_dataTable.clear();
 							
-							// ログ出力
-							if(m_log.isDebugEnabled()){
-								m_log.debug("set VarBind " + m_ipAddress + "," + nextOid);
-							}
-							
-							nextStartOids.add(m_startOids.get(i));
-							nextStopOids.add(m_stopOids.get(i));
-							nxt.addVarBind(new SnmpVarBind(nextOid));
-							lastPollingOids.add(nextOid);
+							// nxtが空となるためポーリングは継続されない
 						}
-					} else {
-						// リトライ回数をリセット
-						m_indexCheckRetryCount = 0;
+						
+						// リトライ回数をカウントアップ
+						m_indexCheckDiffIndexRetryCount++;
+						m_indexCheckVarBindSizeRetryCount = 0;
+						m_indexCheckRetryCountTotal++;
+					} else if(lastPollingOids.size() != m_lastPollingOids.size()) {  // エラーパターン4の対応
+						// ログ出力
+						if (m_log.isDebugEnabled()){
+							m_log.debug("recovery(next count:" + lastPollingOids.size() + ") "
+									+ m_ipAddress);
+						}
+						
+//						// 格納されたMIB値を削除します。
+//						for(int j=0; j < pdu.getLength(); j++){
+//							String removeOid = pdu.getVarBindAt(j).getName().toString();
+//							m_log.debug("remove " + m_ipAddress + ", " + removeOid);
+//							m_dataTable.removeValue(removeOid);
+//						}
+
+						nextStartOids.clear();
+						nextStopOids.clear();
+						lastPollingOids.clear();
+						nxt = new SnmpPduRequest(SnmpPduPacket.GETNEXT);
+						nxt.setRequestId(SnmpPduPacket.nextSequence());
+						
+						// 最大リトライ回数（デフォルト3回）までは、同じOIDでリトライ処理
+						// 永遠に同じOIDでリトライ処理が実行されないように、最大リトライ回数を超えたものは、
+						// IF文分岐の下のロジックを通る
+						if(m_indexCheckVarBindSizeRetryCount < MAX_RETRY_COUNT){
+							for (int i = 0; i < m_lastPollingOids.size(); i++) {
+								String nextOid = m_lastPollingOids.get(i);
+
+								nextStartOids.add(m_startOids.get(i));
+								nextStopOids.add(m_stopOids.get(i));
+								nxt.addVarBind(new SnmpVarBind(nextOid));
+								lastPollingOids.add(nextOid);
+							
+								// ログ出力
+								if (m_log.isDebugEnabled()) {
+									m_log.debug("set VarBind " + m_ipAddress + "," + nextOid);
+								}
+							}
+						} else { // リトライ回数の上限を超えた場合
+							m_log.error("too many retries(VarBind size not match). " + m_ipAddress 
+									+ " count:" + m_indexCheckVarBindSizeRetryCount);
+							// 収集したデータを全てクリアする
+							m_dataTable.clear();
+							
+							// nxtが空となるためポーリングは継続されない
+						}
+							
+						// リトライ回数をカウントアップ
+						m_indexCheckDiffIndexRetryCount = 0;
+						m_indexCheckVarBindSizeRetryCount++;
+						m_indexCheckRetryCountTotal++;
 					}
 				}
 			}
-			
+
 			if (nxt.getLength() != 0) {
 				m_startOids = nextStartOids;
 				m_stopOids = nextStopOids;
@@ -589,11 +691,15 @@ public class SnmpPoller implements SnmpHandler {
 				synchronized (session) {
 					session.notify();
 				}
+				
 				return;
 			}
 		} catch (Exception e) { // 何か例外が生じた場合は収集を停止する
 			m_log.error("InternalError ", e);
 
+			// 収集したデータを全てクリアする
+			m_dataTable.clear();
+			
 			// 収集を終了します
 			synchronized (session) {
 				m_errorCode = InternalError;
@@ -610,19 +716,19 @@ public class SnmpPoller implements SnmpHandler {
 	 */
 	public void snmpInternalError(SnmpSession session, int err, SnmpSyntax pdu) {
 		String message = "InternalError. The error code is " + err + ". IP:"
-				+ m_ipAddress + " OID:" + m_oidText[0];
+		+ m_ipAddress + " OID:" + m_oidText[0];
 		m_log.error("snmpInternalError():" + session.toString() + " " + message);
 
 		synchronized (session) {
 			m_errorCode = InternalError;
 			m_message = message;
-			
+
 			// 既に収集されたものも含めて全て削除する
 			for (int j = 0; j < m_oidText.length; j++) {
 				// 収集中のOID配下のOIDの値をテーブルから削除
 				removeTableValue(m_oidText[j]);
 			}
-			
+
 			m_waitFlg = false;
 			session.notify();
 		}
@@ -634,35 +740,36 @@ public class SnmpPoller implements SnmpHandler {
 	 */
 	public void snmpTimeoutError(SnmpSession session, SnmpSyntax pdu) {
 //		m_log.warn("snmpTimeoutError():"
-//				+ session.getPeer().getPeer().toString() + " "
-//				+ ((SnmpPduRequest) pdu).toVarBindArray()[0].getName()
-//				+ " polling failed at TimeoutError");
-		
+//		+ session.getPeer().getPeer().toString() + " "
+//		+ ((SnmpPduRequest) pdu).toVarBindArray()[0].getName()
+//		+ " polling failed at TimeoutError");
+
 		SnmpVarBind[] bind = ((SnmpPduRequest) pdu).toVarBindArray();
 		String ipAddress = session.getPeer().getPeer().toString();
 		String message = "Polling failed at TimeoutError." + " IP:" + ipAddress
-				+ " OID:" + bind[0].getName();
-		
+		+ " OID:" + bind[0].getName();
+
 		// より詳細なメッセージを作成
 		String addMessage = "";
 		if(m_log.isDebugEnabled()){
 			for (int i = 1; i < bind.length; i++) {
 				addMessage = addMessage + "\n\t" + ipAddress + " " + bind[i].getName();
 			}
+			message = message + addMessage;
 		}
-		
-		m_log.warn(message + addMessage);
-				
+
+		m_log.warn(message);
+
 		synchronized (session) {
 			m_errorCode = TimeOutError;
 			m_message = message;
-			
+
 			// 既に収集されたものも含めて全て削除する
 			for (int j = 0; j < m_oidText.length; j++) {
 				// 収集中のOID配下のOIDの値をテーブルから削除
 				removeTableValue(m_oidText[j]);
 			}
-			
+
 			session.notify();
 		}
 	}
@@ -685,7 +792,7 @@ public class SnmpPoller implements SnmpHandler {
 		Set<String> oidSet = m_dataTable.keySet();
 
 		String[] fullOids = (String[]) oidSet
-				.toArray(new String[oidSet.size()]);
+		.toArray(new String[oidSet.size()]);
 
 		for (int i = 0; i < fullOids.length; i++) {
 
@@ -728,7 +835,7 @@ public class SnmpPoller implements SnmpHandler {
 
 		// ポーリングを行い値を収集
 		DataTable dataTable = new DataTable();
-		
+
 		poller.polling(
 				ipAddress, 
 				port,
@@ -739,7 +846,7 @@ public class SnmpPoller implements SnmpHandler {
 				oids, 
 				indexCheckFlg,
 				dataTable);
-		
+
 		Set<String> keyset = dataTable.keySet();
 		// OID順に並び替える
 		TreeSet<String> keys = new TreeSet<String>(keyset);
@@ -750,7 +857,7 @@ public class SnmpPoller implements SnmpHandler {
 		while(keyItr.hasNext()){
 			ts.add(dataTable.getValue(keyItr.next()));
 		}
-		
+
 		// 取得値の一覧を表示
 		Iterator<ValueObject> itr = ts.iterator();
 		while(itr.hasNext()){
